@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -18,15 +18,15 @@
   MagickCore Application Programming Interface declarations.
 */
 
-#ifndef _MAGICKCORE_API_DEPRECATED_H
-#define _MAGICKCORE_API_DEPRECATED_H
+#ifndef MAGICKCORE_API_DEPRECATED_H
+#define MAGICKCORE_API_DEPRECATED_H
+
+#include "magick/MagickCore.h"
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
 
-#include "magick/MagickCore.h"
-
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
