@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -15,16 +15,16 @@
 
   MagickCore exception methods.
 */
-#ifndef _MAGICKCORE_EXCEPTION_H
-#define _MAGICKCORE_EXCEPTION_H
+#ifndef MAGICKCORE_EXCEPTION_H
+#define MAGICKCORE_EXCEPTION_H
+
+#include <stdarg.h>
+#include "magick/semaphore.h"
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
 
-#include <stdarg.h>
-#include "magick/semaphore.h"
-
 typedef enum
 {
   UndefinedException,
@@ -144,6 +144,7 @@ extern MagickExport ErrorHandler
 
 extern MagickExport ExceptionInfo
   *AcquireExceptionInfo(void),
+  *CloneExceptionInfo(ExceptionInfo *),
   *DestroyExceptionInfo(ExceptionInfo *);
 
 extern MagickExport FatalErrorHandler
@@ -154,15 +155,14 @@ extern MagickExport MagickBooleanType
     const char *),
   ThrowMagickException(ExceptionInfo *,const char *,const char *,const size_t,
     const ExceptionType,const char *,const char *,...)
-    magick_attribute((format (printf,7,8))),
+    magick_attribute((__format__ (__printf__,7,8))),
   ThrowMagickExceptionList(ExceptionInfo *,const char *,const char *,
     const size_t,const ExceptionType,const char *,const char *,va_list)
-    magick_attribute((format (printf,7,0)));
+    magick_attribute((__format__ (__printf__,7,0)));
 
 extern MagickExport void
   CatchException(ExceptionInfo *),
   ClearMagickException(ExceptionInfo *),
-  GetExceptionInfo(ExceptionInfo *),
   InheritException(ExceptionInfo *,const ExceptionInfo *),
   MagickError(const ExceptionType,const char *,const char *),
   MagickFatalError(const ExceptionType,const char *,const char *),
