@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -15,8 +15,8 @@
 
   MagickCore digital signature methods.
 */
-#ifndef _MAGICKCORE_SIGNATURE_H
-#define _MAGICKCORE_SIGNATURE_H
+#ifndef MAGICKCORE_SIGNATURE_H
+#define MAGICKCORE_SIGNATURE_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
