@@ -27,10 +27,10 @@ extern "C" {
 */
 #define MagickPackageName "ImageMagick"
 #define MagickCopyright  "Copyright (C) 1999-2016 ImageMagick Studio LLC"
-#define MagickLibVersion  0x693
-#define MagickLibVersionText  "6.9.3"
+#define MagickLibVersion  0x694
+#define MagickLibVersionText  "6.9.4"
 #define MagickLibVersionNumber  2,0,0
-#define MagickLibAddendum  "-0"
+#define MagickLibAddendum  "-10"
 #define MagickLibInterface  2
 #define MagickLibMinInterface  2
 #if defined(_WINDOWS)
@@ -40,14 +40,14 @@ extern "C" {
 #    define MagickPlatform "x86"
 #  endif
 #else
-#define MagickPlatform  "mips64"
+#define MagickPlatform  "x86_64"
 #endif
-#define MagickppLibVersionText  "6.9.3"
+#define MagickppLibVersionText  "6.9.4"
 #define MagickppLibVersionNumber  6:0:0
-#define MagickppLibAddendum  "-0"
+#define MagickppLibAddendum  "-10"
 #define MagickppLibInterface  6
 #define MagickppLibMinInterface  6
-#define MagickReleaseDate  "2016-02-29"
+#define MagickReleaseDate  "2016-07-25"
 #define MagickHomeURL  "file:///usr/local/share/doc/ImageMagick/index.html"
 #define MagickAuthoritativeLicense  \
   "http://www.imagemagick.org/script/license.php"
